@@ -1,19 +1,14 @@
 from rest_framework import serializers
 
-from data.models.models import CalibrationConstants, Calibration, Channel, Accessory, HardwareConfig, PiPico, \
+from data.models.models import  Channel, Accessory, HardwareConfig, PiPico, \
     DHT22, MCP3008, ModProbe, VEML7700, Hardware, Hub, SPIIo, SerialIo, PwmIo, I2cIo, DeviceFileIo, MCPAnalogIo, \
-    PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer,DataTransformerConstants,DataTransformerTypes,ChannelStats
+    PiPicoAnalogIo, PiPicoACAnalogIo, PiGpio, DataTransformer,DataTransformerConstants,DataTransformerTypes,ChannelStats,ChannelStatDataPoint
 
 class RecursiveField(serializers.Serializer):
     def to_representation(self, value):
         serializer = self.parent.parent.__class__(value, context=self.context)
         return serializer.data
 
-class CalibrationConstantsSerializer(serializers.ModelSerializer):
-    class Meta:
-        model = CalibrationConstants
-        fields = ['id', 'type', 'value']
-
 
 class HubSerializer(serializers.ModelSerializer):
     class Meta:
@@ -21,14 +16,6 @@ class HubSerializer(serializers.ModelSerializer):
         fields = '__all__'
 
 
-class CalibrationSerializer(serializers.ModelSerializer):
-    calibration_constants = CalibrationConstantsSerializer(source='calibrationconstants_set', many=True,
-                                                           read_only=False)
-
-    class Meta:
-        model = Calibration
-        fields = ['id', 'type', 'calibration_constants']
-
 class ChannelStatsSerializer(serializers.ModelSerializer):
     channel = serializers.PrimaryKeyRelatedField(read_only=True)
     model = serializers.SerializerMethodField()
@@ -42,6 +29,13 @@ class ChannelStatsSerializer(serializers.ModelSerializer):
         model = ChannelStats
         fields = ['id', 'channel', 'type', 'value','model']
 
+class ChannelStatDataPointSerializer(serializers.ModelSerializer):
+    channel = serializers.PrimaryKeyRelatedField(read_only=True)
+
+    class Meta:
+        model = ChannelStatDataPoint
+        fields = ['channel','value']
+
 class ChannelSerializer(serializers.ModelSerializer):
     channelstats_set = ChannelStatsSerializer(read_only=True,many=True, required=False)
     model = serializers.SerializerMethodField()
@@ -294,7 +288,6 @@ class DataTransformerTreeSerializer(serializers.ModelSerializer):
 
 class AccessorySerializer(serializers.ModelSerializer):
     # channels = ChannelSerializer(source='channel_set', many=True)
-    calibration = CalibrationSerializer(source='calibration_set', many=True, read_only=False)
     datatransformer = DataTransformerTreeSerializer(read_only=True)
     model = serializers.SerializerMethodField()
 
@@ -307,4 +300,4 @@ class AccessorySerializer(serializers.ModelSerializer):
     class Meta:
         model = Accessory
         fields = ['id', 'category', 'type', 'display_name', 'aid',
-                  'calibration', 'channels','datatransformer','model']
\ No newline at end of file
+                   'channels','datatransformer','model']
\ No newline at end of file
